import javax.swing.*;
import java.awt.event.*;
import java.awt.GridLayout;

/**
 * Lab #7
 * CS 2334, Section 0??
 * DATE GOES HERE
 * <P>
 * This class implements a dialog box that can be used
 * to input the data associated with a movie.
 * </P>
 * @author Group #??
 * @version 1.0
 */
@SuppressWarnings("serial")
public class MovieDialog extends JDialog implements ActionListener
{
	/** Data model for the dialog box. */
	private Movie dataModel;
	/** Static constant that indicates the user clicked on "OK" */
	public static final int OK_OPTION = 1;
	/** Static constant that indicates the user clicked on "CANCEL" */
	public static final int CANCEL_OPTION = 0;
	/** Text field for the title of the movie */
	private JTextField title_field;
	/** Text field for the year of the movie */
	JTextField year_field;
	/** Button for closing the dialog and saving changes. */
	JButton ok_button;
	/** Button for closing the dialog and not saving any changes. */
	JButton cancel_button;
	/** Indicates how the dialog was closed. */
	int close_option;
	
	/**
	 * Initializes the GUI for the dialog box.
	 * <P>
	 * @param   ownerFrame   Frame this dialog is to be attached to.
	 * @param   model        Data model to use for this dialog.
	 */
	MovieDialog( JFrame ownerFrame, Movie model )
	{

		/* Call the constructor of the super class (JDialog) and 
		 * to initialize the dialog object. */
		super( ownerFrame, true );


		/* Save a reference to the object serving as the data model
		 * for the dialog. */
		dataModel = model;
		
		
		/* Create components to add to the dialog and setup any necessary
		 * event listeners. */

		JLabel title_label;
		title_label = new JLabel("Title: ");
		title_field = new JTextField(10);
		
		JLabel year_label;
		year_label = new JLabel("Year: ");
		year_field = new JTextField(10);
		
		ok_button = new JButton("OK");
		cancel_button = new JButton("CANCEL");

		ok_button.addActionListener(this);
		cancel_button.addActionListener(this);
		
		// Change the layout manager
		getContentPane().setLayout(new GridLayout(0,2));
		
		/* Add the components to the content pane of the dialog. */

		getContentPane().add( title_label );
		getContentPane().add( title_field );

		getContentPane().add( year_label );
		getContentPane().add( year_field );

		getContentPane().add( ok_button );
		getContentPane().add( cancel_button );

		// Initialize the class variable that indicates how the dialog was closed.
		close_option = CANCEL_OPTION;

		// Resize the dialog so that it fit's it's contents.
		pack();
	}

	/**
	 * Returns a value indicating how the user closed the dialog.
	 * <P>
	 * @return  An integer indicating how the user closed the dialog
	 *          (will be either the constant OK_OPTION or CANCEL_OPTION.
	 */
	public int getCloseOption()
	{
		return close_option;
	}

	/**
	 * Method serving as the action event handler for the dialog.
	 * <P>
	 * @param  e  An instance of ActionEvent representing the event that
	 *            occurred.
	 */
	public void actionPerformed( ActionEvent e )
	{
		System.out.println(e);

		if(e.getSource()== ok_button)
		{
			/* The user chose to save changes, copy entered data into the data model. */
			dataModel.setTitle(title_field.getText());
			dataModel.setYear(Integer.parseInt(year_field.getText()));
			/* Record that the user clicked on OK to close the dialog. */
			close_option = OK_OPTION;
		}
		
		if(e.getSource()== cancel_button)
		{
			/* Record that the user clicked on CANCEL to close the dialog. */
			close_option = CANCEL_OPTION;			
		}
		
		// Close the dialog.
		dispose();
	}
}
