import java.awt.event.*;
import javax.swing.*;
import java.awt.BorderLayout;
import java.io.IOException;

/**
 * Lab #7 CS 2334, Section 0?? 
 * DATE GOES HERE
 * <P>
 * This class implements a GUI based program that allows an inventory of movies
 * to the manipulated.
 * </P>
 * 
 * @author Group #??
 * @version 1.0
 */
public class MovieGUI implements ActionListener {
	/** Main frame for the program. */
	private JFrame frame;
	/** List to display the movies in. */
	private JList movies;
	/** Button to add a movie. */
	private JButton addButton;
	/** Button to remove a movie. */
	private JButton removeButton;
	/** Data model for holding the movies. */
	private MovieListModel listModel;

	/**
	 * Initializes the data model for the program and initializes all GUI
	 * components associated with the program.
	 * <P>
	 * 
	 * @param appFrame
	 *            JFrame to use as the window for the program.
	 * @param model
	 *            Data model for holding a list of movies.
	 */
	MovieGUI(JFrame appFrame, MovieListModel model) {
		// Save a reference to the frame for the GUI.
		frame = appFrame;

		// Save a reference to the data model for the program.
		listModel = model;

		// Setup the default close operation for the JFrame.
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

		// Create A list to hold movies in and initialize it.
		movies = new JList(listModel.getVector());

		// Create a scroll pane to the hold the list.
		JScrollPane scrollPane = new JScrollPane(movies);

		// Create JButtons for the program.
		addButton = new JButton("Add");
		addButton.addActionListener(this);

		removeButton = new JButton("Remove");
		removeButton.addActionListener(this);

		// Create panel to hold the buttons.
		JPanel buttonPanel = new JPanel();

		// Add buttons to the button panel.
		buttonPanel.add(addButton);
		buttonPanel.add(removeButton);

		// Add button panel and list to the frame.
		frame.getContentPane().add(scrollPane, BorderLayout.CENTER);
		frame.getContentPane().add(buttonPanel, BorderLayout.SOUTH);

		// Size the frame and make it show up.
		frame.setSize(300, 400);
		frame.setVisible(true);
	}

	/**
	 * Implements the action listener for the GUI. Handles the events of clicking
	 * on the Add or Remove buttons.
	 * <P>
	 * 
	 * @param e
	 *            An object representing the Action Event that occurred.
	 */
	public void actionPerformed(ActionEvent e) {
		if (e.getSource() == addButton) {
			// If the user clicked on Add, then add a movie.
			addMovie();
		} else if (e.getSource() == removeButton) {
			// If the user clicked on Remove, then remove the selected movie.
			removeMovie();
		}
	}

	/**
	 * Removes the selected movie from the list of movies.
	 */
	public void removeMovie() {
		// Determine which movie is selected.
		int index = movies.getSelectedIndex();

		/*
		 * If index < 0, then no movie is selected, so do nothing. Otherwise
		 * remove the selected movie. A good modification here would be to
		 * display a message box to the user when they click on the remove
		 * button without first selection an item in the list.
		 */
		if (index > -1) {
			listModel.remove(index);
			movies.setListData(listModel.getVector());
		}
	}

	/**
	 * Adds a new movie to the list of movies.
	 */
	@SuppressWarnings("deprecation")
	public void addMovie() {
		// Create a data model to hold the new movie.
		Movie dataModel = new Movie();

		/*
		 * Create and display a dialog box that allows the user to enter the
		 * data associated with the movie.
		 */
		MovieDialog dialog = new MovieDialog(frame, dataModel);
		dialog.show();

		/*
		 * Determine how the user closed the dialog. If they closed it by
		 * affirming that they want the data saved, then add the movie to the
		 * list of movies.
		 */
		if (dialog.getCloseOption() == MovieDialog.OK_OPTION) {
			listModel.add(dataModel);
			movies.setListData(listModel.getVector());
		}
	}

	/**
	 * This is the main method of the program. It creates an initial lists of
	 * movies and creates a GUI that allows the list to be manipulated.
	 * <P>
	 * 
	 * @param args
	 *            Any command line arguments. This program does not use command
	 *            line arguments.
	 */
	public static void main(String args[]) {
		/* Data model for the program. */
		MovieListModel movies;
		/* Frame for the GUI of the program. */
		JFrame guiFrame;
		/* Movie GUI for the program. */
		@SuppressWarnings("unused")
		MovieGUI gui;

		// Initialize the list movies.
		movies = new MovieListModel();

		/*
		 * 1. Instantiate three objects of type Movie and add them to the list
		 * movies.
		 */
		Movie movie1 = new Movie("Movie1", 1);
		Movie movie2 = new Movie("Movie2", 2);
		Movie movie3 = new Movie("Movie3", 3);
		// xx ...

		/*
		 * The list is referenced to by the variable movies. You can add to the
		 * list by invoking the add method if ArrayList.
		 */
		movies.add(movie1);
		movies.add(movie2);
		movies.add(movie3);
		// xx ...

		// Create a frame for the program.
		guiFrame = new JFrame("Movie Inventory System");

		// Create GUI.
		gui = new MovieGUI(guiFrame, movies);

	}

	/**
	 * Uses the data model to store the inventory out to a user specified
	 * data file.
	 */
	private void saveAction()
	{
		boolean success = false;
		do
		{
			/* Query the user for the file to use.
			 * Start the dialog in the current directory by passing
			 * JFileChooser a . as the path.
			 */
			JFileChooser chooser = new JFileChooser(".");
			int returnVal = chooser.showSaveDialog(frame);
			if(returnVal == JFileChooser.APPROVE_OPTION) 
			{
				try {
					listModel.saveToFile( chooser.getSelectedFile().getPath() );
					success = true;
				} 
				catch( IOException ioe )
				{
					/* If there was an error saving the file, let the user know
					 * and give them a chance to try again.
					 */
					JOptionPane.showMessageDialog(frame,
					"Could Not Open File!" );
				}
			}
			else
			{
				success = true;
			}
		} while( success == false ); /* Loop iterates until the file has been
		 * successfully written or the user CANCELS the operation. */
	}

	/**
	 * Uses the data model to load the inventory from a user specified
	 * data file.
	 */
	private void loadAction()
	{
		boolean success = false;
		do
		{
			/* Query the user for the file to use.
			 * Start the dialog in the current directory by passing
			 * JFileChooser a . as the path.
			 */
			JFileChooser chooser = new JFileChooser(".");
			int returnVal = chooser.showOpenDialog(frame);
			if(returnVal == JFileChooser.APPROVE_OPTION) 
			{
				try {
					// Load from the file.
					listModel.loadFromFile( chooser.getSelectedFile().getPath() );

					// Update the display.
					movies.setListData( listModel.getVector() );
					success = true;
				} 
				catch( IOException ioe )
				{
					/* If there was an error opening the file, let the user know
					 * and give them a chance to try again.
					 */
					JOptionPane.showMessageDialog(frame,
					"Could Not Open File!" );
				}
				catch( ClassNotFoundException cnfe )
				{
					/* If there was an error reading the file, let the user know
					 * and give them a chance to try again.
					 */
					JOptionPane.showMessageDialog(frame,
					"Could Not Read Selected File!" );
				}
			}
			else
			{
				success = true;
			}
		} while( success == false ); /* Loop iterates until the file has been
		 * successfully written or the user CANCELS the operation. */
	}


}
